Parameter

Struct Parameter 

pub struct Parameter {
Show 13 fields pub novalue: bool, pub semiverbatim: Option<Vec<char>>, pub optional: bool, pub name: SymStr, pub spec: SymStr, pub extra: Vec<Tokens>, pub inner: Option<Parameters>, pub reader: ReaderClosure, pub predigest: Option<ReaderPredigestClosure>, pub reversion: Option<ReversionClosure>, pub digested_reversion: Option<DigestedReversionClosure>, pub before_digest: Vec<BeforeDigestClosure>, pub after_digest: Vec<DigestionClosure>,
}

Fields

novalue: boolsemiverbatim: Option<Vec<char>>optional: boolname: SymStrspec: SymStrextra: Vec<Tokens>inner: Option<Parameters>reader: ReaderClosurepredigest: Option<ReaderPredigestClosure>reversion: Option<ReversionClosure>digested_reversion: Option<DigestedReversionClosure>

Reversion closure that operates on the original Digested argument. Takes precedence over reversion when the argument is a digested value. Perl equivalent: reversion option on DefParameterType with undigested => 1.

before_digest: Vec<BeforeDigestClosure>after_digest: Vec<DigestionClosure>

Implementations

Source

impl Parameter

pub fn new<T: AsRef<str>>( name: T, spec: T, extra: Option<Vec<Tokens>>, ) -> Result<Self>

pub fn init(self) -> Result<Self>

pub fn check_reader_function(name: &str) -> Option<ReaderClosure>

Obtain the reader of a given parameter name, if available

pub fn setup_catcodes(&self)

pub fn revert_catcodes(&self) -> Result<()>

pub fn read(&self, fordefn: Option<&dyn Definition>) -> Result<ArgWrap>

pub fn digest( &self, value_arg: ArgWrap, _fordefn: Option<&Constructor>, ) -> Result<Option<Digested>>

pub fn revert(&self, value_opt: Option<Tokens>) -> Result<Option<Tokens>>

pub fn reparse(&self, tokens: Tokens) -> Result<ArgWrap>

This is needed by structured parameter types like KeyVals where the argument may already have been tokenized before the KeyVals (and the parameter types for the keys) had a chance to properly parse.